@@ -141,13 +141,7 @@ def read_File_path(source:Path, delimiter:str, name) -> list:
     return data_list 
    
 def read_csv_file(source: Path, delimiter: str):
-    """Load csv files from disk.
-    Args:
-        source (Path): Path of a single csv file or a directory containing csvs to be parsed;
-        delimiter (str): Separator for columns in csv.
-    Return:
-        Dict: Dict of data extracted of csv.
-    """
+  
     if source.is_file():
         log.info("Reading Single File %s", source)
         data = read_File_single_arch(source, delimiter)
@@ -185,7 +179,7 @@ def read_csv_file(source: Path, delimiter: str):
     )
 ) 
 def converter2(input : str = './', output: str = './', prefix: str = None):
-    """Convert a single file or list of csv to Json.
+    """converter aqui.
     """
     input_path = Path(input)
     output_path = Path(output)
@@ -250,26 +244,20 @@ def parse_json_to_csv(data) -> list:
     return list_header_body
     
 def read_json_File_single_arch(source:Path) -> list:
-    """Read a single archive csv."""
+    """Leitura do arquivo csv."""
     with open(source,'r') as file:
         data = file.readlines()
     return data
     
 def read_json_File_path(source:Path, name) -> list:
-    """Read archives from an Path"""
+    """leitura path"""
     with open(name,"r") as file:
       data = file.readlines()
     return data    
 
 
 def read_json_file(source: Path):
-    """Load csv files from disk.
-    Args:
-        source (Path): Path of a single csv file or a directory containing csvs to be parsed;
-        delimiter (str): Separator for columns in csv.
-    Return:
-        Dict: Dict of data extracted of csv.    
-    """
+ 
     if source.is_file():
         log.info("Reading Single File %s", source)
         data_json = read_json_File_single_arch(source)
